==> blanco.plugin.dbee_1.4.1-src.zip: blancoDbPlugin/src/blanco/plugin/dbee/wizards/BlancoDbEEWizardPage99.java <==
/*
 * blancoDb Enterprise Edition
 * Copyright (C) 2004-2005 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.dbee.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.dbee.editors.BlancoDbEEEditor;

public class BlancoDbEEWizardPage99 extends WizardPage {

    private ISelection selection;

    public BlancoDbEEWizardPage99(ISelection selection) {
        super("wizardPage");
        setTitle("blancoDbEEvOCpxEBU[h̊");
        this.selection = selection;
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoDbEEvOCpxEBU[h Ŋ܂B");
        new Label(container, SWT.NONE)
                .setText("  1.EBU[h ublancoDbݒt@C GfB^v\܂B");
        new Label(container, SWT.NONE).setText("    ̉ʂ "
                + BlancoDbEEEditor.TARGET_FILENAME + "t@C̃GfB^vOɑ܂B");
        new Label(container, SWT.NONE).setText("  2.ʕ\ɏ]đi߂ĂB");

        setControl(container);
    }
}

==> blanco.plugin.dbee_1.6.4-src.zip: blancoDbPlugin/src/blanco/plugin/dbee/wizards/BlancoDbEEWizardPage99.java <==
/*
 * blancoDb Enterprise Edition
 * Copyright (C) 2004-2005 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.dbee.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.dbee.editors.BlancoDbEEEditor;

public class BlancoDbEEWizardPage99 extends AbstractBlancoDbEEWizardPage99 {
    public BlancoDbEEWizardPage99(ISelection selection) {
        super(selection);
        setTitle("blancoDbEEvOCpxEBU[h̊");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoDbEEvOCpxEBU[h Ŋ܂B");
        new Label(container, SWT.NONE)
                .setText("  1.EBU[h ublancoDbݒt@C GfB^v\܂B");
        new Label(container, SWT.NONE).setText("    ̉ʂ "
                + BlancoDbEEEditor.TARGET_FILENAME + "t@C̃GfB^vOɑ܂B");
        new Label(container, SWT.NONE).setText("  2.ʕ\ɏ]đi߂ĂB");

        setControl(container);
    }
}
